==> imsdk_client_flutter-0.0.7.tar.gz: lib/app/widget/widget_button.dart <==
import 'package:flutter/material.dart';

///
///徽章标记
///
class WidgetButton extends StatelessWidget {
  static const double defaultSize = 40;

  final Clip clipBehavior;
  final double elevation;
  final double? minWidth;
  final double height;
  final EdgeInsets padding;
  final ShapeBorder? shape;
  final bool border;
  final double? borderSize;
  final Color? borderColor;
  final BorderRadius? radius;
  final Widget? child;
  final Widget? subChild;
  final double subSpace;
  final Color? color;
  final VoidCallback? onPressed;
  final VoidCallback? onLongPressed;

  const WidgetButton({
    Key? key,
    this.clipBehavior = Clip.none,
    this.elevation = 0,
    this.minWidth,
    this.height = defaultSize,
    this.padding = EdgeInsets.zero,
    this.shape,
    this.border = false,
    this.borderSize,
    this.borderColor,
    this.radius,
    this.child,
    this.subChild,
    this.subSpace = 0,
    this.color,
    this.onPressed,
    this.onLongPressed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    return MaterialButton(
      visualDensity: VisualDensity.standard,
      materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
      clipBehavior: clipBehavior,
      elevation: elevation,
      hoverElevation: elevation,
      focusElevation: elevation,
      disabledElevation: elevation,
      highlightElevation: elevation,
      minWidth: minWidth,
      height: height,
      padding: padding,
      shape: shape ?? _getRoundedRectangleBorder(themeData, border, borderSize: borderSize, borderColor: borderColor, borderRadius: radius),
      color: color,
      onPressed: onPressed,
      onLongPress: onLongPressed,
      child: subChild == null
          ? child
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [child ?? const SizedBox(), SizedBox(height: subSpace), subChild ?? const SizedBox()],
            ),
    );
  }

  ///获取细的浅色边框
  ShapeBorder _getRoundedRectangleBorder(ThemeData themeData, bool border, {double? borderSize, Color? borderColor, BorderRadius? borderRadius}) {
    return RoundedRectangleBorder(
      side: border ? BorderSide(width: borderSize ?? themeData.dividerTheme.space ?? 0.5, color: borderColor ?? themeData.dividerColor) : BorderSide.none,
      borderRadius: borderRadius ?? BorderRadius.zero,
    );
  }

  ///获取细的浅色边框
  static InputBorder getOutlineInputBorder(ThemeData themeData, {double? borderSize, Color? borderColor, BorderRadius? borderRadius}) {
    return OutlineInputBorder(
      borderSide: BorderSide(width: borderSize ?? themeData.dividerTheme.space ?? 0.5, color: borderColor ?? themeData.dividerColor),
      borderRadius: borderRadius ?? BorderRadius.zero,
    );
  }

  static double getBorderSize(ThemeData themeData, {double? borderSize}) => borderSize ?? themeData.dividerTheme.space ?? 0.5;
}

==> imsdk_client_flutter-0.0.19.tar.gz: lib/app/widget/widget_button.dart <==
import 'package:flutter/material.dart';

///
///徽章标记
///
class WidgetButton extends StatelessWidget {
  static const double defaultSize = 40;

  final Clip clipBehavior;
  final double elevation;
  final double? minWidth;
  final double height;
  final EdgeInsets padding;
  final ShapeBorder? shape;
  final bool border;
  final double? borderSize;
  final Color? borderColor;
  final BorderRadius? radius;
  final Widget? child;
  final Widget? subChild;
  final double subSpace;
  final Color? color;
  final VoidCallback? onPressed;
  final VoidCallback? onLongPressed;

  const WidgetButton({
    Key? key,
    this.clipBehavior = Clip.none,
    this.elevation = 0,
    this.minWidth,
    this.height = defaultSize,
    this.padding = EdgeInsets.zero,
    this.shape,
    this.border = false,
    this.borderSize,
    this.borderColor,
    this.radius,
    this.child,
    this.subChild,
    this.subSpace = 0,
    this.color,
    this.onPressed,
    this.onLongPressed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    return MaterialButton(
      visualDensity: VisualDensity.standard,
      materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
      clipBehavior: clipBehavior,
      elevation: elevation,
      hoverElevation: elevation,
      focusElevation: elevation,
      disabledElevation: elevation,
      highlightElevation: elevation,
      minWidth: minWidth,
      height: height,
      padding: padding,
      shape: shape ?? _getRoundedRectangleBorder(themeData, border, borderSize: borderSize, borderColor: borderColor, borderRadius: radius),
      color: color,
      onPressed: onPressed,
      onLongPress: onLongPressed,
      child: subChild == null
          ? child
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [child ?? const SizedBox(), SizedBox(height: subSpace), subChild ?? const SizedBox()],
            ),
    );
  }

  ///获取细的浅色边框
  ShapeBorder _getRoundedRectangleBorder(ThemeData themeData, bool border, {double? borderSize, Color? borderColor, BorderRadius? borderRadius}) {
    return RoundedRectangleBorder(
      side: border ? BorderSide(width: borderSize ?? themeData.dividerTheme.space ?? 0.5, color: borderColor ?? themeData.dividerColor) : BorderSide.none,
      borderRadius: borderRadius ?? BorderRadius.zero,
    );
  }

  ///获取细的浅色边框
  static InputBorder getOutlineInputBorder(ThemeData themeData, bool border, {double? borderSize, Color? borderColor, BorderRadius? borderRadius}) {
    return OutlineInputBorder(
      borderSide: border ? BorderSide(width: borderSize ?? themeData.dividerTheme.space ?? 0.5, color: borderColor ?? themeData.dividerColor) : BorderSide.none,
      borderRadius: borderRadius ?? BorderRadius.zero,
    );
  }

  static double getBorderSize(ThemeData themeData, {double? borderSize}) => borderSize ?? themeData.dividerTheme.space ?? 0.5;
}
